@@ -26,5 +26,26 @@ utils::globalVariables(c(
   "xmax",
   "ymin",
   "ymax",
-  "where"
+  "where",
+  "Death",
+  "Alive",
+  "disc",
+  "Tstop",
+  "Tstart",
+  "from",
+  "to",
+  "trans",
+  "status",
+  "treat",
+  "Pre-progressed",
+  "Progressed",
+  "Death",
+  "l_12",
+  "l_13",
+  "l_11",
+  "check",
+  "sim_idx",
+  "npeople",
+  "grp_lab",
+  "Group"
 ))
\ No newline at end of file
